@@ -22,7 +22,6 @@
 #include "libxml++/parsers/domparser.h"
 #include "libxml++/relaxngschema.h"
 
-#include <libxml/tree.h>
 #include <libxml/relaxng.h>
 
 namespace xmlpp
@@ -73,7 +72,7 @@ void RelaxNGValidator::parse_file(const Glib::ustring& filename)
 
 void RelaxNGValidator::parse_memory(const Glib::ustring& contents)
 {
-  std::unique_ptr<RelaxNGSchema> schema(new RelaxNGSchema());
+  std::auto_ptr<RelaxNGSchema> schema(new RelaxNGSchema());
   schema->parse_memory(contents);
   set_schema(schema.release(), true);
 }
@@ -133,7 +132,7 @@ void RelaxNGValidator::initialize_valid()
 void RelaxNGValidator::validate(const Document* document)
 {
   if (!document)
-    throw internal_error("RelaxNGValidator::validate(): document must not be nullptr.");
+    throw internal_error("RelaxNGValidator::validate(): document must not be 0.");
 
   if (!*this)
     throw internal_error("RelaxNGValidator::validate(): Must have a schema to validate document");
